
from gi.repository import GObject

_namespace: str = ...
_version: str = ...

def module_build_path(*args, **kwargs): ...
def module_error(*args, **kwargs): ...
def module_supported(*args, **kwargs): ...

class Module:
    def build_path(*args, **kwargs): ...
    def close(*args, **kwargs): ...
    def error(*args, **kwargs): ...
    def make_resident(*args, **kwargs): ...
    def name(*args, **kwargs): ...
    def supported(*args, **kwargs): ...
    def symbol(*args, **kwargs): ...
    

class ModuleFlags(GObject.GFlags):
    LAZY = ...
    LOCAL = ...
    MASK = ...
